@@ -147,13 +147,15 @@ def read(url, show_log=None, **options):
     else:
         pix_fmt_in = s_in = None
 
-    # get url/file stream
-    url, stdin, input = configure.check_url(url, False)
-
     input_options = utils.pop_extra_options(options, "_in")
 
+    # get url/file stream
+    url, stdin, input = configure.check_url(
+        url, False, format=input_options.get("f", None)
+    )
+
     ffmpeg_args = configure.empty()
-    configure.add_url(ffmpeg_args, "input", url, input_options)[1][1]
+    configure.add_url(ffmpeg_args, "input", url, input_options)
     outopts = configure.add_url(ffmpeg_args, "output", "-", options)[1][1]
     outopts["f"] = "rawvideo"
     if "frames:v" not in outopts:
